"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Textarea } from "@/components/ui/textarea"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import {
  Clock,
  CheckCircle,
  AlertCircle,
  MessageSquare,
  DollarSign,
  User,
  Settings,
  LogOut,
  Star,
  Search,
  Filter,
  Upload,
  Download,
  Eye,
  Send,
  Target,
  Award,
  PenTool,
  Briefcase,
  RefreshCw,
} from "lucide-react"
import { getAuthenticatedUser, logout, hasRole } from "@/lib/auth"
import { useAvailableOrders, useOrdersByWriter, useDataActions } from "@/hooks/use-data-store"
import Link from "next/link"

export default function WriterDashboard() {
  const router = useRouter()
  const [user, setUser] = useState<any>(null)
  const [isLoading, setIsLoading] = useState(true)
  const [activeTab, setActiveTab] = useState("available")

  // Data from store
  const availableOrders = useAvailableOrders()
  const myOrders = useOrdersByWriter(user?.email || "")
  const { addWriterApplication, updateOrder } = useDataActions()

  // Filter states
  const [searchFilter, setSearchFilter] = useState("")
  const [subjectFilter, setSubjectFilter] = useState("all")
  const [levelFilter, setLevelFilter] = useState("all")
  const [urgencyFilter, setUrgencyFilter] = useState("all")

  // Application states
  const [selectedOrder, setSelectedOrder] = useState<any>(null)
  const [bidAmount, setBidAmount] = useState("")
  const [proposalText, setProposalText] = useState("")
  const [showBidModal, setShowBidModal] = useState(false)

  useEffect(() => {
    const authenticatedUser = getAuthenticatedUser()

    if (!authenticatedUser || !hasRole("writer")) {
      router.push("/auth/login")
      return
    }

    setUser(authenticatedUser)
    setIsLoading(false)
  }, [router])

  const handleLogout = () => {
    logout()
  }

  const getStatusBadge = (status: string) => {
    switch (status) {
      case "assigned":
        return (
          <Badge variant="default">
            <AlertCircle className="w-3 h-3 mr-1" />
            Assigned
          </Badge>
        )
      case "in_progress":
        return (
          <Badge variant="default">
            <AlertCircle className="w-3 h-3 mr-1" />
            In Progress
          </Badge>
        )
      case "completed":
        return (
          <Badge variant="secondary" className="bg-green-100 text-green-800">
            <CheckCircle className="w-3 h-3 mr-1" />
            Completed
          </Badge>
        )
      case "revision":
        return (
          <Badge variant="outline" className="border-yellow-500 text-yellow-700">
            <RefreshCw className="w-3 h-3 mr-1" />
            Revision Required
          </Badge>
        )
      case "submitted":
        return (
          <Badge variant="outline">
            <Clock className="w-3 h-3 mr-1" />
            Under Review
          </Badge>
        )
      default:
        return <Badge variant="outline">{status}</Badge>
    }
  }

  const getUrgencyBadge = (urgency: string) => {
    switch (urgency) {
      case "high":
        return <Badge variant="destructive">Urgent</Badge>
      case "normal":
        return <Badge variant="outline">Normal</Badge>
      case "low":
        return <Badge variant="secondary">Flexible</Badge>
      default:
        return <Badge variant="outline">{urgency}</Badge>
    }
  }

  const handleApplyForOrder = (order: any) => {
    setSelectedOrder(order)
    setBidAmount(order.budget.toString())
    setProposalText("")
    setShowBidModal(true)
  }

  const submitApplication = () => {
    if (!selectedOrder || !user) return

    const application = {
      id: `APP-${Date.now()}`,
      orderId: selectedOrder.id,
      writerId: user.email,
      writerName: user.name || user.email.split("@")[0],
      writerEmail: user.email,
      writerRating: 4.8, // Default rating for demo
      bidAmount: Number(bidAmount),
      proposal: proposalText,
      appliedDate: new Date().toISOString(),
      status: "pending" as const,
      experience: "5+ years", // Default for demo
      specializations: ["Academic Writing", "Research"],
    }

    addWriterApplication(application)

    alert(
      `Application submitted successfully for "${selectedOrder.title}"!\n\nBid Amount: $${bidAmount}\n\nYour application has been sent to the admin for review. You'll be notified once a decision is made.`,
    )

    setShowBidModal(false)
    setSelectedOrder(null)
    setBidAmount("")
    setProposalText("")
  }

  const updateOrderProgress = (orderId: string, newProgress: number) => {
    updateOrder(orderId, { progress: newProgress })
  }

  const submitWork = (orderId: string) => {
    updateOrder(orderId, {
      status: "submitted",
      progress: 100,
      lastUpdate: new Date().toISOString(),
    })
    alert("Work submitted successfully! The client will review and provide feedback.")
  }

  const startWork = (orderId: string) => {
    updateOrder(orderId, {
      status: "in_progress",
      lastUpdate: new Date().toISOString(),
    })
  }

  const filteredAvailableOrders = availableOrders.filter((order) => {
    const matchesSearch =
      order.title.toLowerCase().includes(searchFilter.toLowerCase()) ||
      order.description.toLowerCase().includes(searchFilter.toLowerCase())
    const matchesSubject = subjectFilter === "all" || order.subject === subjectFilter
    const matchesLevel = levelFilter === "all" || order.academicLevel === levelFilter
    const matchesUrgency = urgencyFilter === "all" || order.urgency === urgencyFilter

    return matchesSearch && matchesSubject && matchesLevel && matchesUrgency
  })

  // Calculate writer stats
  const writerStats = {
    activeOrders: myOrders.filter((o) => o.status === "in_progress" || o.status === "assigned").length,
    completedOrders: myOrders.filter((o) => o.status === "completed").length,
    averageRating: 4.7,
    successRate: 95,
    onTimeDelivery: 98,
    thisMonthEarnings: myOrders
      .filter((o) => o.status === "completed" && new Date(o.completedDate || "").getMonth() === new Date().getMonth())
      .reduce((sum, o) => sum + o.amount, 0),
  }

  if (isLoading) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <div className="text-center">
          <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary mx-auto mb-4"></div>
          <p>Loading dashboard...</p>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen dashboard-academic">
      {/* Header */}
      <header className="dashboard-header-academic">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center py-6">
            <div className="flex items-center">
              <div className="w-10 h-10 bg-primary rounded-xl flex items-center justify-center">
                <PenTool className="h-6 w-6 text-white" />
              </div>
              <span className="ml-3 text-xl font-bold text-gray-900">ProEssayWorks Writer</span>
            </div>
            <div className="flex items-center space-x-6">
              <span className="body-academic-regular text-gray-600">
                Welcome back, <span className="font-semibold text-gray-900">{user?.name}</span>
              </span>
              <div className="flex items-center space-x-2">
                <Link href="/writer/messages">
                  <Button variant="ghost" size="sm" className="font-medium">
                    <MessageSquare className="h-4 w-4 mr-2" />
                    Messages
                  </Button>
                </Link>
                <Button variant="ghost" size="sm" className="font-medium">
                  <User className="h-4 w-4 mr-2" />
                  Profile
                </Button>
                <Button variant="ghost" size="sm" className="font-medium">
                  <Settings className="h-4 w-4 mr-2" />
                  Settings
                </Button>
                <Button
                  variant="ghost"
                  size="sm"
                  onClick={handleLogout}
                  className="font-medium text-red-600 hover:text-red-700"
                >
                  <LogOut className="h-4 w-4 mr-2" />
                  Logout
                </Button>
              </div>
            </div>
          </div>
        </div>
      </header>

      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        {/* Welcome Section */}
        <div className="mb-12">
          <h1 className="heading-academic-secondary text-gray-900 mb-3">Welcome back, {user?.name}!</h1>
          <p className="body-academic-large text-gray-600">Find new opportunities and manage your writing projects</p>
        </div>

        {/* Stats Cards */}
        <div className="grid grid-cols-1 md:grid-cols-5 gap-6 mb-12">
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">Active Orders</CardTitle>
              <Briefcase className="h-5 w-5 text-blue-600" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">{writerStats.activeOrders}</div>
              <p className="body-academic-small text-blue-600 mt-1">Currently working</p>
            </CardContent>
          </Card>
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">This Month</CardTitle>
              <DollarSign className="h-5 w-5 text-green-600" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">${writerStats.thisMonthEarnings}</div>
              <p className="body-academic-small text-green-600 mt-1">Earnings</p>
            </CardContent>
          </Card>
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">Rating</CardTitle>
              <Star className="h-5 w-5 text-yellow-600" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">{writerStats.averageRating}</div>
              <p className="body-academic-small text-yellow-600 mt-1">Excellent rating</p>
            </CardContent>
          </Card>
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">Success Rate</CardTitle>
              <Target className="h-5 w-5 text-purple-600" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">{writerStats.successRate}%</div>
              <p className="body-academic-small text-purple-600 mt-1">Outstanding performance</p>
            </CardContent>
          </Card>
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">Available</CardTitle>
              <Clock className="h-5 w-5 text-orange-600" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">{availableOrders.length}</div>
              <p className="body-academic-small text-orange-600 mt-1">New orders</p>
            </CardContent>
          </Card>
        </div>

        {/* Main Content */}
        <Tabs value={activeTab} onValueChange={setActiveTab} className="space-y-6">
          <TabsList className="grid w-full grid-cols-4">
            <TabsTrigger value="available">Available Orders ({availableOrders.length})</TabsTrigger>
            <TabsTrigger value="my-orders">My Orders ({myOrders.length})</TabsTrigger>
            <TabsTrigger value="earnings">Earnings</TabsTrigger>
            <TabsTrigger value="profile">Profile</TabsTrigger>
          </TabsList>

          <TabsContent value="available" className="space-y-6">
            {/* Filters */}
            <Card className="dashboard-card-academic">
              <CardHeader>
                <CardTitle className="heading-academic-tertiary">Find Orders</CardTitle>
                <CardDescription className="body-academic-regular text-gray-600">
                  Browse and apply for new writing opportunities
                </CardDescription>
              </CardHeader>
              <CardContent>
                <div className="grid grid-cols-1 md:grid-cols-5 gap-4 mb-6">
                  <div className="relative">
                    <Search className="absolute left-2 top-2.5 h-4 w-4 text-gray-400" />
                    <Input
                      placeholder="Search orders..."
                      className="pl-8"
                      value={searchFilter}
                      onChange={(e) => setSearchFilter(e.target.value)}
                    />
                  </div>
                  <Select value={subjectFilter} onValueChange={setSubjectFilter}>
                    <SelectTrigger>
                      <SelectValue placeholder="Subject" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">All Subjects</SelectItem>
                      <SelectItem value="Environmental Science">Environmental Science</SelectItem>
                      <SelectItem value="Business Administration">Business Administration</SelectItem>
                      <SelectItem value="Computer Science">Computer Science</SelectItem>
                      <SelectItem value="Psychology">Psychology</SelectItem>
                      <SelectItem value="History">History</SelectItem>
                      <SelectItem value="Marketing">Marketing</SelectItem>
                    </SelectContent>
                  </Select>
                  <Select value={levelFilter} onValueChange={setLevelFilter}>
                    <SelectTrigger>
                      <SelectValue placeholder="Level" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">All Levels</SelectItem>
                      <SelectItem value="high_school">High School</SelectItem>
                      <SelectItem value="undergraduate">Undergraduate</SelectItem>
                      <SelectItem value="masters">Master's</SelectItem>
                      <SelectItem value="phd">PhD</SelectItem>
                    </SelectContent>
                  </Select>
                  <Select value={urgencyFilter} onValueChange={setUrgencyFilter}>
                    <SelectTrigger>
                      <SelectValue placeholder="Urgency" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">All Urgency</SelectItem>
                      <SelectItem value="high">Urgent</SelectItem>
                      <SelectItem value="normal">Normal</SelectItem>
                      <SelectItem value="low">Flexible</SelectItem>
                    </SelectContent>
                  </Select>
                  <Button variant="outline" className="btn-outline">
                    <Filter className="h-4 w-4 mr-2" />
                    More Filters
                  </Button>
                </div>

                <div className="space-y-6">
                  {filteredAvailableOrders.length === 0 ? (
                    <div className="text-center py-12">
                      <Briefcase className="h-16 w-16 text-gray-300 mx-auto mb-4" />
                      <h3 className="text-lg font-semibold text-gray-900 mb-2">No orders available</h3>
                      <p className="text-gray-600 mb-6">Check back later for new writing opportunities</p>
                      <Button variant="outline" onClick={() => window.location.reload()}>
                        Refresh Orders
                      </Button>
                    </div>
                  ) : (
                    filteredAvailableOrders.map((order) => (
                      <div key={order.id} className="border rounded-lg p-6 hover:bg-gray-50 transition-colors">
                        <div className="flex justify-between items-start mb-4">
                          <div className="flex-1">
                            <div className="flex items-center space-x-3 mb-2">
                              <h3 className="font-semibold text-lg">{order.title}</h3>
                              {getUrgencyBadge(order.urgency)}
                              <Badge variant="outline" className="text-green-600 border-green-600">
                                ${order.budget}
                              </Badge>
                            </div>
                            <p className="text-gray-600 text-sm mb-4 line-clamp-2">{order.description}</p>

                            <div className="grid grid-cols-2 md:grid-cols-4 gap-4 text-sm text-gray-600 mb-4">
                              <div>
                                <span className="font-medium">Subject:</span> {order.subject}
                              </div>
                              <div>
                                <span className="font-medium">Level:</span> {order.academicLevel}
                              </div>
                              <div>
                                <span className="font-medium">Pages:</span> {order.pages}
                              </div>
                              <div>
                                <span className="font-medium">Deadline:</span>{" "}
                                {new Date(order.deadline).toLocaleDateString()}
                              </div>
                              <div>
                                <span className="font-medium">Posted:</span>{" "}
                                {new Date(order.postedDate).toLocaleDateString()}
                              </div>
                              <div>
                                <span className="font-medium">Applications:</span> {order.bidsCount}
                              </div>
                              <div className="flex items-center">
                                <span className="font-medium mr-1">Client:</span>
                                <Star className="h-3 w-3 text-yellow-500 mr-1" />
                                {order.clientRating}
                              </div>
                              <div>
                                <span className="font-medium">Files:</span> {order.attachments.length}
                              </div>
                            </div>

                            <div className="mb-4">
                              <p className="text-sm font-medium text-gray-700 mb-1">Requirements:</p>
                              <p className="text-sm text-gray-600">{order.requirements}</p>
                            </div>
                          </div>
                        </div>

                        <div className="flex justify-between items-center">
                          <div className="flex space-x-3">
                            <Button
                              size="sm"
                              className="btn-academic-primary"
                              onClick={() => handleApplyForOrder(order)}
                            >
                              Apply for Order
                            </Button>
                            <Button variant="outline" size="sm">
                              <Eye className="h-4 w-4 mr-1" />
                              View Details
                            </Button>
                            {order.attachments.length > 0 && (
                              <Button variant="outline" size="sm">
                                <Download className="h-4 w-4 mr-1" />
                                Files ({order.attachments.length})
                              </Button>
                            )}
                          </div>
                          <div className="text-right">
                            <p className="text-lg font-bold text-green-600">${order.budget}</p>
                            <p className="text-xs text-gray-500">~${(order.budget / order.pages).toFixed(0)}/page</p>
                          </div>
                        </div>
                      </div>
                    ))
                  )}
                </div>
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="my-orders" className="space-y-6">
            <Card className="dashboard-card-academic">
              <CardHeader>
                <CardTitle className="heading-academic-tertiary">My Orders</CardTitle>
                <CardDescription className="body-academic-regular text-gray-600">
                  Track and manage your current and completed projects
                </CardDescription>
              </CardHeader>
              <CardContent>
                {myOrders.length === 0 ? (
                  <div className="text-center py-12">
                    <Clock className="h-16 w-16 text-gray-300 mx-auto mb-4" />
                    <h3 className="text-lg font-semibold text-gray-900 mb-2">No assigned orders</h3>
                    <p className="text-gray-600 mb-6">Apply for available orders to start earning</p>
                    <Button className="btn-academic-primary" onClick={() => setActiveTab("available")}>
                      Browse Available Orders
                    </Button>
                  </div>
                ) : (
                  <div className="space-y-6">
                    {myOrders.map((order) => (
                      <div key={order.id} className="border rounded-lg p-6">
                        <div className="flex justify-between items-start mb-4">
                          <div className="flex-1">
                            <div className="flex items-center space-x-3 mb-2">
                              <h3 className="font-semibold text-lg">{order.title}</h3>
                              {getStatusBadge(order.status)}
                              <div className="flex items-center">
                                <Star className="h-4 w-4 text-yellow-500 mr-1" />
                                <span className="text-sm">{order.clientRating}</span>
                              </div>
                            </div>
                            <p className="text-sm text-gray-600 mb-3">
                              Order ID: {order.id} • Client: {order.clientName}
                            </p>

                            <div className="grid grid-cols-2 md:grid-cols-4 gap-4 text-sm text-gray-600 mb-4">
                              <div>
                                <span className="font-medium">Pages:</span> {order.pages}
                              </div>
                              <div>
                                <span className="font-medium">Deadline:</span>{" "}
                                {new Date(order.deadline).toLocaleDateString()}
                              </div>
                              <div>
                                <span className="font-medium">Amount:</span> ${order.amount}
                              </div>
                              <div>
                                <span className="font-medium">Subject:</span> {order.subject}
                              </div>
                              <div>
                                <span className="font-medium">Assigned:</span>{" "}
                                {order.assignedDate ? new Date(order.assignedDate).toLocaleDateString() : "N/A"}
                              </div>
                              <div>
                                <span className="font-medium">Last Update:</span>{" "}
                                {new Date(order.lastUpdate).toLocaleDateString()}
                              </div>
                              <div>
                                <span className="font-medium">Messages:</span> {order.messages}
                              </div>
                              <div>
                                <span className="font-medium">Progress:</span> {order.progress}%
                              </div>
                            </div>

                            <div className="mb-4">
                              <p className="text-sm font-medium text-gray-700 mb-1">Requirements:</p>
                              <p className="text-sm text-gray-600">{order.requirements}</p>
                            </div>

                            {order.status === "revision" && order.revisionNotes && (
                              <div className="mb-4 p-3 bg-yellow-50 border border-yellow-200 rounded-lg">
                                <p className="text-sm font-medium text-yellow-800 mb-1">Revision Notes:</p>
                                <p className="text-sm text-yellow-700">{order.revisionNotes}</p>
                              </div>
                            )}

                            {order.status === "completed" && order.clientFeedback && (
                              <div className="mb-4 p-3 bg-green-50 border border-green-200 rounded-lg">
                                <p className="text-sm font-medium text-green-800 mb-1">Client Feedback:</p>
                                <p className="text-sm text-green-700">{order.clientFeedback}</p>
                              </div>
                            )}

                            {(order.status === "in_progress" || order.status === "revision") && (
                              <div className="mb-4">
                                <div className="flex justify-between text-sm mb-1">
                                  <span>Progress</span>
                                  <span>{order.progress}%</span>
                                </div>
                                <div className="w-full bg-gray-200 rounded-full h-2">
                                  <div
                                    className="bg-primary h-2 rounded-full transition-all duration-300"
                                    style={{ width: `${order.progress}%` }}
                                  ></div>
                                </div>
                              </div>
                            )}
                          </div>
                        </div>

                        <div className="flex justify-between items-center">
                          <div className="flex space-x-3">
                            {order.status === "assigned" && (
                              <Button size="sm" className="btn-academic-primary" onClick={() => startWork(order.id)}>
                                Start Working
                              </Button>
                            )}
                            {order.status === "in_progress" && (
                              <>
                                <Button
                                  size="sm"
                                  className="btn-academic-primary"
                                  onClick={() => submitWork(order.id)}
                                  disabled={order.progress < 100}
                                >
                                  <Upload className="h-4 w-4 mr-2" />
                                  Submit Work
                                </Button>
                                <Select onValueChange={(value) => updateOrderProgress(order.id, Number(value))}>
                                  <SelectTrigger className="w-40">
                                    <SelectValue placeholder="Update Progress" />
                                  </SelectTrigger>
                                  <SelectContent>
                                    <SelectItem value="25">25% Complete</SelectItem>
                                    <SelectItem value="50">50% Complete</SelectItem>
                                    <SelectItem value="75">75% Complete</SelectItem>
                                    <SelectItem value="100">100% Complete</SelectItem>
                                  </SelectContent>
                                </Select>
                              </>
                            )}
                            {order.status === "revision" && (
                              <Button size="sm" className="btn-academic-primary">
                                <Upload className="h-4 w-4 mr-2" />
                                Submit Revision
                              </Button>
                            )}
                            <Link href={`/writer/messages?order=${order.id}`}>
                              <Button variant="outline" size="sm">
                                <MessageSquare className="h-4 w-4 mr-2" />
                                Message Client ({order.messages})
                              </Button>
                            </Link>
                            <Button variant="outline" size="sm">
                              <Eye className="h-4 w-4 mr-2" />
                              View Details
                            </Button>
                          </div>
                          <div className="text-right">
                            <p className="text-lg font-bold text-green-600">${order.amount}</p>
                            <p className="text-xs text-gray-500">
                              {order.status === "completed" ? "Earned" : "Will Earn"}
                            </p>
                          </div>
                        </div>
                      </div>
                    ))}
                  </div>
                )}
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="earnings" className="space-y-6">
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
              <Card className="dashboard-card-academic">
                <CardHeader>
                  <CardTitle className="heading-academic-tertiary">Earnings Overview</CardTitle>
                </CardHeader>
                <CardContent className="space-y-6">
                  <div className="grid grid-cols-2 gap-4">
                    <div className="text-center p-4 bg-green-50 rounded-lg">
                      <p className="text-sm text-gray-600 mb-1">Total Earnings</p>
                      <p className="text-2xl font-bold text-green-600">
                        ${myOrders.filter((o) => o.status === "completed").reduce((sum, o) => sum + o.amount, 0)}
                      </p>
                    </div>
                    <div className="text-center p-4 bg-blue-50 rounded-lg">
                      <p className="text-sm text-gray-600 mb-1">This Month</p>
                      <p className="text-2xl font-bold text-blue-600">${writerStats.thisMonthEarnings}</p>
                    </div>
                  </div>

                  <div className="space-y-3">
                    <div className="flex justify-between items-center">
                      <span>Available Balance</span>
                      <span className="text-lg font-semibold text-green-600">$320</span>
                    </div>
                    <div className="flex justify-between items-center">
                      <span>Pending Payments</span>
                      <span className="text-lg font-semibold text-yellow-600">
                        $
                        {myOrders
                          .filter((o) => o.status === "in_progress" || o.status === "submitted")
                          .reduce((sum, o) => sum + o.amount, 0)}
                      </span>
                    </div>
                  </div>

                  <Button className="w-full btn-academic-primary">
                    <DollarSign className="h-4 w-4 mr-2" />
                    Request Withdrawal
                  </Button>

                  <p className="text-xs text-gray-500 text-center">
                    Withdrawals are processed within 3-5 business days
                  </p>
                </CardContent>
              </Card>

              <Card className="dashboard-card-academic">
                <CardHeader>
                  <CardTitle className="heading-academic-tertiary">Performance Metrics</CardTitle>
                </CardHeader>
                <CardContent className="space-y-6">
                  <div className="grid grid-cols-2 gap-4">
                    <div className="text-center p-4 bg-yellow-50 rounded-lg">
                      <Star className="h-8 w-8 text-yellow-500 mx-auto mb-2" />
                      <p className="text-2xl font-bold text-yellow-600">{writerStats.averageRating}</p>
                      <p className="text-sm text-gray-600">Average Rating</p>
                    </div>
                    <div className="text-center p-4 bg-green-50 rounded-lg">
                      <Target className="h-8 w-8 text-green-500 mx-auto mb-2" />
                      <p className="text-2xl font-bold text-green-600">{writerStats.successRate}%</p>
                      <p className="text-sm text-gray-600">Success Rate</p>
                    </div>
                  </div>

                  <div className="space-y-4">
                    <div>
                      <div className="flex justify-between text-sm mb-1">
                        <span>On-Time Delivery</span>
                        <span>{writerStats.onTimeDelivery}%</span>
                      </div>
                      <div className="w-full bg-gray-200 rounded-full h-2">
                        <div
                          className="bg-green-600 h-2 rounded-full"
                          style={{ width: `${writerStats.onTimeDelivery}%` }}
                        ></div>
                      </div>
                    </div>

                    <div>
                      <div className="flex justify-between text-sm mb-1">
                        <span>Client Satisfaction</span>
                        <span>96%</span>
                      </div>
                      <div className="w-full bg-gray-200 rounded-full h-2">
                        <div className="bg-blue-600 h-2 rounded-full" style={{ width: "96%" }}></div>
                      </div>
                    </div>
                  </div>

                  <div className="pt-4 border-t">
                    <h4 className="font-semibold mb-2">Achievements</h4>
                    <div className="space-y-2">
                      <div className="flex items-center space-x-2">
                        <Award className="h-4 w-4 text-gold" />
                        <span className="text-sm">Top Performer</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <CheckCircle className="h-4 w-4 text-green-600" />
                        <span className="text-sm">{writerStats.completedOrders}+ Orders Completed</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Star className="h-4 w-4 text-yellow-500" />
                        <span className="text-sm">5-Star Rating Streak</span>
                      </div>
                    </div>
                  </div>
                </CardContent>
              </Card>
            </div>
          </TabsContent>

          <TabsContent value="profile" className="space-y-6">
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
              <Card className="dashboard-card-academic">
                <CardHeader>
                  <CardTitle className="heading-academic-tertiary">Writer Profile</CardTitle>
                  <CardDescription>Manage your professional profile and specializations</CardDescription>
                </CardHeader>
                <CardContent className="space-y-4">
                  <div>
                    <Label htmlFor="bio">Professional Bio</Label>
                    <Textarea
                      id="bio"
                      placeholder="Describe your expertise and experience..."
                      rows={4}
                      defaultValue="Experienced academic writer with 5+ years in research and content creation. Specialized in environmental science, business analysis, and technical writing."
                    />
                  </div>

                  <div>
                    <Label htmlFor="education">Education</Label>
                    <Input
                      id="education"
                      placeholder="Your highest degree and institution"
                      defaultValue="PhD in Environmental Science, Stanford University"
                    />
                  </div>

                  <div>
                    <Label htmlFor="experience">Years of Experience</Label>
                    <Select defaultValue="5-10">
                      <SelectTrigger>
                        <SelectValue />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectItem value="1-2">1-2 years</SelectItem>
                        <SelectItem value="3-5">3-5 years</SelectItem>
                        <SelectItem value="5-10">5-10 years</SelectItem>
                        <SelectItem value="10+">10+ years</SelectItem>
                      </SelectContent>
                    </Select>
                  </div>

                  <div>
                    <Label>Specializations</Label>
                    <div className="flex flex-wrap gap-2 mt-2">
                      {["Environmental Science", "Business Analysis", "Technical Writing", "Research Methods"].map(
                        (spec) => (
                          <Badge key={spec} variant="outline">
                            {spec}
                          </Badge>
                        ),
                      )}
                    </div>
                    <Button variant="outline" size="sm" className="mt-2">
                      Add Specialization
                    </Button>
                  </div>

                  <Button className="w-full btn-academic-primary">Update Profile</Button>
                </CardContent>
              </Card>

              <Card className="dashboard-card-academic">
                <CardHeader>
                  <CardTitle className="heading-academic-tertiary">Recent Activity</CardTitle>
                  <CardDescription>Your latest actions and updates</CardDescription>
                </CardHeader>
                <CardContent>
                  <div className="space-y-4">
                    {myOrders.slice(0, 5).map((order) => (
                      <div key={order.id} className="flex items-center space-x-3 p-3 border rounded-lg">
                        <div className="flex-shrink-0">
                          {order.status === "completed" ? (
                            <CheckCircle className="h-5 w-5 text-green-600" />
                          ) : order.status === "in_progress" ? (
                            <Clock className="h-5 w-5 text-blue-600" />
                          ) : (
                            <AlertCircle className="h-5 w-5 text-yellow-600" />
                          )}
                        </div>
                        <div className="flex-1 min-w-0">
                          <p className="text-sm font-medium text-gray-900 truncate">{order.title}</p>
                          <p className="text-xs text-gray-500">
                            {order.status === "completed"
                              ? "Completed"
                              : order.status === "in_progress"
                                ? `${order.progress}% complete`
                                : "Assigned"}
                          </p>
                        </div>
                        <div className="text-xs text-gray-400">{new Date(order.lastUpdate).toLocaleDateString()}</div>
                      </div>
                    ))}
                  </div>
                </CardContent>
              </Card>
            </div>
          </TabsContent>
        </Tabs>
      </div>

      {/* Bid Modal */}
      {showBidModal && selectedOrder && (
        <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50">
          <div className="bg-white rounded-lg p-6 w-full max-w-2xl mx-4">
            <h3 className="text-lg font-semibold mb-4">Apply for Order: {selectedOrder.title}</h3>

            <div className="space-y-4">
              <div>
                <Label htmlFor="bidAmount">Your Bid Amount ($)</Label>
                <Input
                  id="bidAmount"
                  type="number"
                  value={bidAmount}
                  onChange={(e) => setBidAmount(e.target.value)}
                  placeholder="Enter your bid amount"
                />
                <p className="text-sm text-gray-600 mt-1">Suggested: ${selectedOrder.budget} (Client's budget)</p>
              </div>

              <div>
                <Label htmlFor="proposal">Proposal</Label>
                <Textarea
                  id="proposal"
                  value={proposalText}
                  onChange={(e) => setProposalText(e.target.value)}
                  placeholder="Explain why you're the best fit for this project..."
                  rows={6}
                />
                <p className="text-sm text-gray-600 mt-1">
                  Highlight your relevant experience and approach to this project.
                </p>
              </div>
            </div>

            <div className="flex justify-end space-x-3 mt-6">
              <Button variant="outline" onClick={() => setShowBidModal(false)}>
                Cancel
              </Button>
              <Button
                className="btn-academic-primary"
                onClick={submitApplication}
                disabled={!bidAmount || !proposalText.trim()}
              >
                <Send className="h-4 w-4 mr-2" />
                Submit Application
              </Button>
            </div>
          </div>
        </div>
      )}
    </div>
  )
}
